@@ -7,7 +7,7 @@
 ##' and the \eqn{\epsilon_t}{eps[t]} are i.i.d. lognormal random deviates with
 ##' variance \eqn{\sigma^2}{sigma^2}.
 ##' The observed variables \eqn{Y_t} are distributed as
-##' \deqn{Y_t\sim\mathrm{lognormal}(\log{X_t},\tau).}{Y[t]~lognormal(log(X[t]),tau).}
+##' \deqn{Y_t\sim\mathrm{Lognormal}(\log{X_t},\tau).}{Y[t]~Lognormal(log(X[t]),tau).}
 ##' Parameters include the per-capita growth rate \eqn{r}, the carrying
 ##' capacity \eqn{K}, the process noise s.d. \eqn{\sigma}{sigma}, the
 ##' measurement error s.d. \eqn{\tau}{tau}, and the initial condition
@@ -52,9 +52,7 @@ gompertz <- function (K = 1, r = 0.1, sigma = 0.1, tau = 0.1, X_0 = 1,
       toEst="_gompertz_to_trans",
       fromEst="_gompertz_from_trans"
     ),
-    rprocess=discrete_time(
-      step.fun="_gompertz_simulator"
-    ),
+    rprocess=discrete_time("_gompertz_step",delta.t=1),
     emeasure="_gompertz_normal_emeasure",
     vmeasure="_gompertz_normal_vmeasure",
     rmeasure="_gompertz_normal_rmeasure",
